@@ -14,16 +14,10 @@
 #' @noRd
 app_ui <- function(request) {
   options(spinner.color="#2c7da3", spinner.color.background="#ffffff", spinner.size = 2)
-  # Add this at the beginning of your app
-  # Add this line at the beginning of your app, outside of the ui and server functions
-  #shiny::addResourcePath("res", system.file("app/www", package = "FielDHub"))
   tagList(
     golem_add_external_resources(),
-    tags$head(tags$script(type="text/javascript", src = "corner.js")),
-    tags$head(tags$script(type="text/javascript", src= "shinybusy.js")), 
-    #includeCSS(system.file("app/www/style.css", package = "FielDHub")),
     fluidPage(theme = shinythemes::shinytheme("flatly"),
-              navbarPage(title = "FielDHub v1.3.4", 
+              navbarPage(title = "FielDHub v1.3.7", 
                          tabPanel(
                            " Welcome!", icon = icon("home", lib = "glyphicon"),
                             suppressWarnings(
@@ -32,14 +26,6 @@ app_ui <- function(request) {
                               )
                             )
                          ),
-                         # tabPanel(" Welcome!",
-                         #          icon = icon("home", lib = "glyphicon"),
-                         #          tags$iframe(
-                         #            src = "res/home.html",
-                         #            width = "100%",  # Adjust width and height as necessary
-                         #            height = "1000px"
-                         #          )
-                         # ),
                          navbarMenu("Unreplicated Designs",
                                     tabPanel("Single Diagonal Arrangement",
                                              mod_Diagonal_ui("Diagonal_ui_1")
