@@ -7,6 +7,7 @@
 #' @param add_checks Option to add checks. Optional if \code{design = "prep"}
 #' @param checks Number of genotypes checks. 
 #' @param rep_checks Replication for each check.
+#' @param force_balance Get balanced unbalanced locations. By default \code{force_balance = TRUE}.
 #' @param data (optional) Data frame with 2 columns: \code{ENTRY | NAME }. ENTRY must be numeric.
 #' @param seed (optional) Real number that specifies the starting seed to obtain reproducible designs.
 #' 
@@ -44,7 +45,8 @@ do_optim <- function(
     copies_per_entry, 
     add_checks = FALSE, 
     checks = NULL, 
-    rep_checks = NULL, 
+    rep_checks = NULL,
+    force_balance = TRUE,
     seed,
     data = NULL) {
     # set a random seed if it is missing
@@ -147,7 +149,7 @@ do_optim <- function(
     # Check if there are unbalanced locations and force them to be balanced
     size_locs <- as.vector(base::colSums(allocation))
     max_size_locs <- max(size_locs)
-    if (!all(size_locs == max_size_locs)) {
+    if (!all(size_locs == max_size_locs) & force_balance == TRUE) {
         unbalanced_locs <- which(size_locs != max_size_locs)
         max_swaps <- length(unbalanced_locs)
         k <- nrow(allocation)
@@ -169,18 +171,18 @@ do_optim <- function(
     colnames(allocation_df) <- paste0("LOC", 1:l)
     # Create a wide data frame with number of copies and average per plant
     col_sum <- base::colSums(allocation_df)
-    wide_allocation <- allocation_df %>%
+    wide_allocation <- allocation_df |>
         dplyr::mutate(
-            copies = rowSums(.),
+            copies = rowSums(dplyr::across(dplyr::everything())),
             avg = copies / l
         )
     # Create a long data frame with the allocations per location
-    long_allocation <- as.data.frame(allocation) %>%
-        dplyr::rename_with(~c("ENTRY", "LOCATION", "REPS"), dplyr::everything()) %>%  # rename columns
+    long_allocation <- as.data.frame(allocation) |>
+        dplyr::rename_with(~c("ENTRY", "LOCATION", "REPS"), dplyr::everything()) |>  # rename columns
         dplyr::mutate(
             LOCATION = gsub("B", "LOC", LOCATION),
             NAME = paste0("G-", ENTRY)
-        ) %>%  
+        ) |>  
         dplyr::select(LOCATION, ENTRY, NAME, REPS)
     # Create a data frame for the checks
     if (design != "prep") {
@@ -210,20 +212,20 @@ do_optim <- function(
     )
     # Generate the lists of entries for each location
     for (site in unique(long_allocation$LOCATION)) {
-        df_loc <- long_allocation %>% 
-            dplyr::filter(LOCATION == site, REPS > 0) %>% 
-            dplyr::mutate(ENTRY = as.numeric(ENTRY)) %>% 
-            dplyr::select(ENTRY, NAME, REPS) %>%
-            dplyr::bind_rows(df_checks) %>%
+        df_loc <- long_allocation |> 
+            dplyr::filter(LOCATION == site, REPS > 0) |> 
+            dplyr::mutate(ENTRY = as.numeric(ENTRY)) |> 
+            dplyr::select(ENTRY, NAME, REPS) |>
+            dplyr::bind_rows(df_checks) |>
             dplyr::arrange(dplyr::desc(ENTRY)) 
 
         if (design == "prep") {
-            df_loc <- df_loc %>% 
+            df_loc <- df_loc |> 
                 dplyr::arrange(dplyr::desc(REPS))
         }
 
         if (design != "prep") {
-            df_loc <- df_loc %>% 
+            df_loc <- df_loc |> 
                 dplyr::select(ENTRY, NAME)
         }
 
@@ -233,13 +235,13 @@ do_optim <- function(
         # Combine the data frames into a single data frame with a new column for the list element name
         multi_location_data <- dplyr::bind_rows(lapply(names(list_locs), function(name) {
             dplyr::mutate(list_locs[[name]], LOCATION = name)
-        })) %>% 
+        })) |> 
             dplyr::select(LOCATION, ENTRY, NAME, REPS)
     } else {
          # Combine the data frames into a single data frame with a new column for the list element name
         multi_location_data <- dplyr::bind_rows(lapply(names(list_locs), function(name) {
             dplyr::mutate(list_locs[[name]], LOCATION = name)
-        })) %>% 
+        })) |> 
             dplyr::select(LOCATION, ENTRY, NAME)
     }
     # out object with the allocation and the list of entries per location
@@ -671,24 +673,25 @@ merge_user_data <- function(
         # Merge each optimized location into the user data input
         for (LOC in locs_range) {
             iter_loc <- optim_out$list_locs[[LOC]]
-            data_input_mutated <- user_data_input %>%
-                dplyr::mutate(
-                    USER_ENTRY = ENTRY,
-                    ENTRY = vlookup_entry
-                ) %>%
-                dplyr::select(USER_ENTRY, ENTRY, NAME) %>%
-                dplyr::left_join(y = iter_loc, by = "ENTRY") %>% 
-                {
-                    if (inherits(optim_out, "MultiPrep")) {
-                        dplyr::select(.data = ., USER_ENTRY, NAME.x, REPS) %>%
-                        dplyr::arrange(dplyr::desc(REPS)) %>%
-                        dplyr::rename(ENTRY = USER_ENTRY, NAME = NAME.x)
-                    } else if (inherits(optim_out, "Sparse")) {
-                        dplyr::filter(.data = ., !is.na(NAME.y)) %>% 
-                        dplyr::select(USER_ENTRY, NAME.x) %>%
-                        dplyr::rename(ENTRY = USER_ENTRY, NAME = NAME.x)
-                    } 
-                }
+            data_input_mutated <- user_data_input |>
+              dplyr::mutate(
+                USER_ENTRY = ENTRY,
+                ENTRY = vlookup_entry
+              ) |>
+              dplyr::select(USER_ENTRY, ENTRY, NAME) |>
+              dplyr::left_join(y = iter_loc, by = "ENTRY")
+
+            if (inherits(optim_out, "MultiPrep")) {
+              data_input_mutated <- data_input_mutated |> 
+              dplyr::select(.data = ., USER_ENTRY, NAME.x, REPS) |>
+                dplyr::arrange(dplyr::desc(REPS)) |>
+                dplyr::rename(ENTRY = USER_ENTRY, NAME = NAME.x)
+            } else if (inherits(optim_out, "Sparse")) {
+              data_input_mutated <- data_input_mutated |> 
+              dplyr::filter(.data = ., !is.na(NAME.y)) |> 
+                dplyr::select(USER_ENTRY, NAME.x) |>
+                dplyr::rename(ENTRY = USER_ENTRY, NAME = NAME.x)
+            } 
             # Store the number of plots (It does not include checks)
             df_to_check <- data_input_mutated[(input_checks + 1):nrow(data_input_mutated), ]
             if (inherits(optim_out, "MultiPrep")) {
